# Sample Test passing with nose and pytest
from .context import Leetx_parser
import os


tests_dir = os.path.dirname(__file__)


def mock_func(url):
    raw_html = open(os.path.join(tests_dir, 'resp.html')).read()
    return raw_html


def test_search():
    lp = Leetx_parser()
    lp._do_request = mock_func
    tors = Leetx_parser().search('the flash s04e01')
    assert True, tors[0]['title'] == 'The.Flash.2014.S04E01.HDTV.x264-LOL[eztv]'




import logging
import requests
import BeautifulSoup


BASE_URL = 'https://1337x.to'
SEARCH_URL = BASE_URL + '/search/{}/1/'


class BadResponse(Exception):
    pass


class NothingFound(Exception):
    pass


class Leetx_parser(object):
    def __init__(self, headers=None):
        self.headers = headers
        self.logger = logging.getLogger(__name__)
        self.logger.info('Package initialized')

    def _do_request(self, url):
        headers = self.headers if self.headers else {'User-Agent': "Magic Browser"}
        resp = requests.get(url, verify=False, headers=headers)
        if 200 != resp.status_code:
            raise BadResponse('url: {} status_code: {}'.format(url, resp.status_code))
        return resp.text

    def search(self, search_str):
        raw_html = self._do_request(SEARCH_URL.format(search_str))
        html = BeautifulSoup.BeautifulSoup(raw_html)
        table = html.find('table', {'class': 'table-list table table-responsive table-striped'})
        if not table:
            raise NothingFound(search_str)
        trs = table.findAll('tr')[1:]
        tors = []
        for tr in trs[0:1]:
            tor = {}
            tds = tr.findAll('td')
            a = tds[0].findAll('a')[-1]
            tor['title'] = a.text
            tor['seeders'] = int(tds[1].text)
            raw_html = self._do_request(BASE_URL + a['href'])
            html = BeautifulSoup.BeautifulSoup(raw_html)
            ul = html.find('ul', {'class': 'download-links-dontblock btn-wrap-list'})
            lis = ul.findAll('li')
            a = lis[0].find('a')
            tor['magnet'] = a['href']
            tors.append(tor)
        return tors


import setuptools

setuptools.setup(
    name="leetx_parser",
    version="0.1.0",
    url="https://github.com/evgeny1602/leetx_parser",

    author="Evgeny Lobanov",
    author_email="evgeny1602@gmail.com",

    description="Find magnet links for TV show episodes",
    long_description=open('README.rst').read(),

    packages=setuptools.find_packages(),

    install_requires=[],

    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
)



"""leetx_parser - Find magnet links for TV show episodes"""

__version__ = '0.1.0'
__author__ = 'Evgeny Lobanov <evgeny1602@gmail.com>'
__all__ = []

import logging
logging.getLogger(__name__).addHandler(logging.NullHandler())